==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/weber/mapping/ActionMapping.java <==
package org.itscool.weber.mapping;

import java.util.HashMap;

/**
 * ActionMappingNX̓AvP[VNɏݒt@C烊NGXgURI
 * ɑΉANVǂݍ݁AێNXłB<BR>
 * ActionMappingCX^X͏ݒt@C̈actionvf
 * ɑΉ܂B<BR>
 * <BR>
 *yݒt@C̐ݒActionMappingNX̃vpeBɑΉ鍀ځz<BR>
 * path F ̃}bsOgpۂ̃NGXgURIp^[<BR>
 * type F ̃}bsOŎgpActionNX<BR>
 * fowards F ̃ANVĂ΂ꂽƂɐnNGXgURIpX<BR>
 * validate F ̃ANVĂ΂ꂽƂ̃tH[`FbNsNXw肷<BR>
 *<BR>
 * ActionMappingNXActionConfigReaderNXɂĐ܂B<BR>
 * ۂɂActionConfigReaderŏt@C[hAActionMappingsNX
 * 𐶐܂B<BR>
 * ActionMappngsNXɂActionMappingNX̃CX^Xc[`Ō`
 * ܂B<BR>
 *
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class ActionMapping{
    /**
     * ANV̘_iTu~bg̃\bhj
     */
	private String path;
	/**
	 * ANV̕ipbP[W܂߂ANVNXj
	 */
    private String type;
    /**
     * tH[IuWFNg̃NXipbP[W܂߂NXj
     */
    private String name;
    /**
     * Jڐ̃Xg
     */
    private HashMap forwards = null;
    /**
     * ̃Xg
     */
    private HashMap roles =null;
    
    /**
     * ANV}bsO܂
     * @param path ANVĂяo߂̃NGXgURI
     * @param type ̃ANVɊ֘AtꂽActionNX
     */
    public ActionMapping(String path, String type, String name){
        this.path = path;
        this.type = type;
        this.name = name;
    }
    
    /**
     * ̃ANVĂ΂郊NGXgURI擾܂
     * @return ̃ANVĂ΂郊NGXgURI
     */
    public String getPath(){
        return path;
    }
    
    /**
     * ̃ANVĂяo߂̃NGXgURIZbg܂
     * @param path ̃ANVĂяo߂̃NGXgURI
     */
    public void setPath(String path){
        this.path = path;
    }
    
    /**
     * ̃ANVɂĂActionNX擾܂
     * @return ̃ANVɂĂActionNX
     */
    public String getType(){
        return type;
    }
    
    /**
     * ̃ANVɂĂActionNXZbg܂
     * @param type ̃ANVɂĂActionNX
     */
    public void setType(String type){
        this.type = type;
    }
    
    /**
     * tH[hǉ܂
     * @param name tH[h̘_
     * @param forward tH[hJSP̃pX
     */
    public void addForward(String name, String forward){
        if( forwards == null){
            forwards = new HashMap();
        }
        forwards.put(name, forward);
    }
    
    /**
     * ̃ANVJډ\ȃtH[hXg擾܂<BR>
     * tH[h񂪒`ĂȂꍇNULLԂ܂
     * @return tH[h̃XgԂ܂
     */
    public HashMap getForwards(){
        return forwards;
    }
	
    /**
     * ̃ANVJڂtH[h擾܂<BR>
     * tH[h񂪒`ĂȂꍇNULLԂ܂
     * @param name tH[hɂĂ_
     * @return tH[hJSP̃pX
     */
    public String getForward(String name){
        return (String)forwards.get(name);
    }
    
    /**
     * ǉ܂ 
     * @param name [
     */
    public void addRole(String name){
        if( roles == null ){
            roles = new HashMap();
        }
        roles.put( name, name);
    }
    
    /**
     * 擾܂<BR>
     * 񂪖ꍇNULLԂ܂
     * @return hashMap ̃ANV錠XgԂ܂
     */
    public HashMap getRoles(){
        return roles;
    }
    
	/**
     * ANV̘_Ԃ܂
	 * @return ANV̘_
	 */
	public String getName() {
		return name;
	}

}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/weber/mapping/ActionMapping.java <==
package org.itscool.weber.mapping;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * ActionMappingNX̓AvP[VNɏݒt@C烊NGXgURI
 * ɑΉANVǂݍ݁AێNXłB<BR>
 * ActionMappingCX^X͏ݒt@C̈actionvf
 * ɑΉ܂B<BR>
 * <BR>
 *yݒt@C̐ݒActionMappingNX̃vpeBɑΉ鍀ځz<BR>
 * path F ̃}bsOgpۂ̃NGXgURIp^[<BR>
 * type F ̃}bsOŎgpActionNX<BR>
 * fowards F ̃ANVĂ΂ꂽƂɐnNGXgURIpX<BR>
 * validate F ̃ANVĂ΂ꂽƂ̃tH[`FbNsNXw肷<BR>
 *<BR>
 * ActionMappingNXActionConfigReaderNXɂĐ܂B<BR>
 * ۂɂActionConfigReaderŏt@C[hAActionMappingsNX
 * 𐶐܂B<BR>
 * ActionMappngsNXɂActionMappingNX̃CX^Xc[`Ō`
 * ܂B<BR>
 *
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class ActionMapping{
    /**
     * ANV̘_iTu~bg̃\bhj
     */
	private String path;
	/**
	 * ANV̕ipbP[W܂߂ANVNXj
	 */
    private String type;
    /**
     * tH[IuWFNg̃NXipbP[W܂߂NXj
     */
    private String name;
    /**
     * Jڐ̃Xg
     */
    private HashMap forwards = null;
    /**
     * ̃Xg
     */
    private HashMap roles =null;
    /**
     * ̓`FbNXg
     */
    private List validates=null;
    
    /**
     * ANV}bsO܂
     * @param path ANVĂяo߂̃NGXgURI
     * @param type ̃ANVɊ֘AtꂽActionNX
     */
    public ActionMapping(String path, String type, String name){
        this.path = path;
        this.type = type;
        this.name = name;
    }
    
    /**
     * ̃ANVĂ΂郊NGXgURI擾܂
     * @return ̃ANVĂ΂郊NGXgURI
     */
    public String getPath(){
        return path;
    }
    
    /**
     * ̃ANVĂяo߂̃NGXgURIZbg܂
     * @param path ̃ANVĂяo߂̃NGXgURI
     */
    public void setPath(String path){
        this.path = path;
    }
    
    /**
     * ̃ANVɂĂActionNX擾܂
     * @return ̃ANVɂĂActionNX
     */
    public String getType(){
        return type;
    }
    
    /**
     * ̃ANVɂĂActionNXZbg܂
     * @param type ̃ANVɂĂActionNX
     */
    public void setType(String type){
        this.type = type;
    }
    
    /**
     * tH[hǉ܂
     * @param name tH[h̘_
     * @param forward tH[hJSP̃pX
     */
    public void addForward(String name, String forward){
        if( forwards == null){
            forwards = new HashMap();
        }
        forwards.put(name, forward);
    }
    
    /**
     * ̃ANVJډ\ȃtH[hXg擾܂<BR>
     * tH[h񂪒`ĂȂꍇNULLԂ܂
     * @return tH[h̃XgԂ܂
     */
    public HashMap getForwards(){
        return forwards;
    }
	
    /**
     * ̃ANVJڂtH[h擾܂<BR>
     * tH[h񂪒`ĂȂꍇNULLԂ܂
     * @param name tH[hɂĂ_
     * @return tH[hJSP̃pX
     */
    public String getForward(String name){
        return (String)forwards.get(name);
    }
    
    /**
     * ǉ܂ 
     * @param name [
     */
    public void addRole(String name){
        if( roles == null ){
            roles = new HashMap();
        }
        roles.put( name, name);
    }

    /**
     * p[^ǉ܂ 
     * @param name p[^
     */
    public void addValidate(ValidationMapping validate){
        if( validates == null ){
        	validates = new ArrayList();
        }
        validates.add(validate);
    }
    
    public List getValidates(){
    	return validates;
    }
    
    /**
     * 擾܂<BR>
     * 񂪖ꍇNULLԂ܂
     * @return hashMap ̃ANV錠XgԂ܂
     */
    public HashMap getRoles(){
        return roles;
    }
    
	/**
     * ANV̘_Ԃ܂
	 * @return ANV̘_
	 */
	public String getName() {
		return name;
	}

}
